@@ -4,7 +4,7 @@
 name = 'plain_db'
 import os
 
-def getFile(fn):
+def getFile(fn, isIntValue=True):
 	result = {}
 	if not os.path.exists(fn):
 		return result
@@ -14,14 +14,16 @@ def getFile(fn):
 			if not line:
 				continue
 			key = ' '.join(line.split()[:-1])
-			value = int(line.split()[-1])
+			value = line.split()[-1]
+			if isIntValue:
+				value = int(value)
 			result[key] = value
 	return result
 
 class DB(object):
-	def __init__(self, name): # first version, int value only
+	def __init__(self, name, isIntValue=True): 
 		self.fn = 'db/' + name
-		self.items = getFile(self.fn)
+		self.items = getFile(self.fn, isIntValue=isIntValue)
 
 	def update(self, key, value):
 		if key not in self.items:
@@ -40,9 +42,9 @@ class DB(object):
 
 	def appendSave(self, key, value):
 		if len(self.items) == 1:
-			prefix = '\n'
-		else:
 			prefix = ''
+		else:
+			prefix = '\n'
 		with open(self.fn, 'a') as f:
 			f.write(prefix + str(key) + ' ' + str(value))
 
@@ -70,5 +72,8 @@ class NoValueDB(object):
 		self._db.update(key, 1)
 		return True
 
+	def items(self):
+		return list(self._db.items.keys())
+
 def loadKeyOnlyDB(fn):
 	return NoValueDB(fn)
